View source: R/extract_interval_helpers.R
| apply_interval_groups | R Documentation |
Apply grouping to intervals
apply_interval_groups(
df_list,
group_channels,
metadata,
group_intervals,
zero_time = FALSE,
verbose = TRUE,
env = rlang::caller_env()
)
verbose |
Logical. |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.