apply_span: apply span to resolved times and build interval_spec data...

View source: R/extract_interval_helpers.R

apply_spanR Documentation

apply span to resolved times and build interval_spec data frame

Description

apply span to resolved times and build interval_spec data frame

Usage

apply_span(
  interval_list,
  t_vec,
  span,
  verbose = TRUE,
  env = rlang::caller_env()
)

Arguments

verbose

Logical. TRUE (default) will display, and FALSE will silence warnings and information messages helpful for troubleshooting. Global default can be set via options(mnirs.verbose = FALSE).

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.