as_mnirs_interval: coerce raw values to mnirs_interval objects

View source: R/extract_interval_helpers.R

as_mnirs_intervalR Documentation

coerce raw values to mnirs_interval objects

Description

coerce raw values to mnirs_interval objects

Usage

as_mnirs_interval(x, arg = "start", env = rlang::caller_env())

Arguments

x

A raw value or mnirs_interval object.

arg

Name of the argument for error messages.

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.