biexp_init: Initiate self-starting biexponential model

View source: R/analyse_biexponential.R

biexp_initR Documentation

Initiate self-starting biexponential model

Description

biexp_init(): Returns initial values for the parameters in a selfStart model.

Usage

biexp_init(mCall, data, LHS, ...)

Arguments

mCall

A matched call to the function model.

data

A data frame with time t and the response variable.

LHS

The left-hand side expression of the model formula.

...

Additional arguments, including fixed, a named list of user-fixed parameter values from init_fixed() used to narrow the grids.

Value

biexp_init(): Initial starting estimates for parameters in the model called by SSbiexponential().


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.