example_mnirs: Get path to _mnirs_ example files

View source: R/read_mnirs.R

example_mnirsR Documentation

Get path to mnirs example files

Description

Get path to mnirs example files

Usage

example_mnirs(file = NULL)

Arguments

file

Name of file as character string. If NULL, returns a vector of all available file names.

Value

A file path character string for selected example files stored in this package.

Examples

## lists all files
example_mnirs()

## partial matching will error if matches multiple
try(example_mnirs("moxy"))

example_mnirs("moxy_ramp")


mnirs documentation built on May 15, 2026, 9:07 a.m.