View source: R/extract_interval_helpers.R
| find_interval_time | R Documentation |
resolve a single mnirs_interval object to time values
find_interval_time(
interval,
t_vec,
event_vec = NULL,
position = c("first", "last"),
env = rlang::caller_env()
)
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.