free_params: Free parameters of a self-start model call

View source: R/aanalyse_kinetics_helpers.R

free_paramsR Documentation

Free parameters of a self-start model call

Description

A parameter written as a bare symbol in the model call is free (fitted by stats::nls()); one written as a constant or expression is fixed. Used by the model functions to return gradient columns for the free parameters only, in call order, as stats::nls() indexes the "gradient" attribute by position.

Usage

free_params(mCall, params)

Arguments

mCall

A matched call to the model function.

params

Character vector of the model parameter names.

Value

A character vector; the subset of params that are free.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.