full_coefs: Combine fitted and fixed coefficients into the full parameter...

View source: R/aanalyse_kinetics_helpers.R

full_coefsR Documentation

Combine fitted and fixed coefficients into the full parameter vector

Description

Combine fitted and fixed coefficients into the full parameter vector

Usage

full_coefs(model, params, fix = list())

Arguments

model

An nls model of the free parameters.

params

Character vector of parameter names in model order.

fix

Named list of fixed parameter values. Non-numeric elements (e.g. a model shape riding in the formula) are ignored.

Value

A named numeric vector ordered by params containing the fitted coefficients with fixed values merged in.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.