logistic_init: Initiate self-starting logistic model

View source: R/analyse_sigmoidal.R

logistic_initR Documentation

Initiate self-starting logistic model

Description

logistic_init(): Returns initial values for the parameters in a selfStart model.

Usage

logistic_init(mCall, data, LHS, ...)

Arguments

mCall

A matched call to the function model.

data

A data frame with predictor t and the response variable.

LHS

The left-hand side expression of the model formula.

...

Additional arguments, including fixed, a named list of user-fixed parameter values from init_fixed() used to seed the remaining free estimates.

Value

logistic_init(): Initial starting estimates for parameters in the model called by SSlogistic().


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.