monoexp_init: Initiate self-starting monoexponential model

View source: R/analyse_monoexponential.R

monoexp_initR Documentation

Initiate self-starting monoexponential model

Description

monoexp_init(): Returns initial values for the parameters in a selfStart model.

Usage

monoexp_init(mCall, data, LHS, ...)

Arguments

mCall

A matched call to the function model.

data

A data frame with time t and the response variable.

LHS

The left-hand side expression of the model formula.

...

Additional arguments, including fixed, a named list of user-fixed parameter values from init_fixed() used to seed the remaining free estimates.

Value

monoexp_init(): Initial starting estimates for parameters in the model called by SSmonoexponential().


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.