oxysoft_sample_rate: Extract the export sample rate from Oxysoft header metadata

View source: R/read_mnirs_helpers.R

oxysoft_sample_rateR Documentation

Extract the export sample rate from Oxysoft header metadata

Description

Extract the export sample rate from Oxysoft header metadata

Usage

oxysoft_sample_rate(header)

Arguments

header

A character data frame of the file rows above the data table.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.