palette_mnirs: Custom _mnirs_ colour palette

View source: R/plot.mnirs.R

palette_mnirsR Documentation

Custom mnirs colour palette

Description

Custom mnirs colour palette

Usage

palette_mnirs(...)

Arguments

...

Either a single numeric specifying the number of colours to return, or character strings specifying colour names. If empty, all colours are returned.

Value

Named (when selecting by name) or unnamed character vector of hex colours.

See Also

theme_mnirs(), scale_colour_mnirs()

Examples


scales::show_col(palette_mnirs())
scales::show_col(palette_mnirs(2))
scales::show_col(palette_mnirs("red", "orange"))


mnirs documentation built on May 15, 2026, 9:07 a.m.