View source: R/validate_mnirs.R
| parse_channel_name | R Documentation |
Converts quosures to character vectors, handling bare symbols, character strings, lists, and tidyselect expressions.
parse_channel_name(channel, data, env = rlang::caller_env())
channel |
A quosure from |
data |
A data frame for tidyselect context. |
env |
Environment for symbol evaluation. |
A character vector, list of character vectors, or NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.