read_file: Read raw data frame from file path

View source: R/read_mnirs_helpers.R

read_fileR Documentation

Read raw data frame from file path

Description

Read raw data frame from file path

Usage

read_file(file_path, env = rlang::caller_env())

Arguments

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.