recycle_param: Recycle parameter to match number of events

View source: R/extract_interval_helpers.R

recycle_paramR Documentation

Recycle parameter to match number of events

Description

Recycle an argument vector to a list or repeat the last list item to match the number of events.

Usage

recycle_param(
  param,
  n_events,
  group_intervals,
  verbose = TRUE,
  env = rlang::caller_env(),
  arg = "values"
)

mnirs documentation built on Sept. 13, 2026, 1:06 a.m.