recycle_span: recycle a single-element span to c(start, end) positive ->...

View source: R/extract_interval_helpers.R

recycle_spanR Documentation

recycle a single-element span to c(start, end) positive -> c(0, x), negative -> c(x, 0)

Description

recycle a single-element span to c(start, end) positive -> c(0, x), negative -> c(x, 0)

Usage

recycle_span(span, env = rlang::caller_env())

Arguments

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.