recycle_to_length: Recycle parameter list to target length

View source: R/extract_interval_helpers.R

recycle_to_lengthR Documentation

Recycle parameter list to target length

Description

Recycle parameter list to target length

Usage

recycle_to_length(
  param,
  n,
  name = c("event", "group"),
  verbose = TRUE,
  env = rlang::caller_env(),
  arg = "values"
)

Arguments

verbose

Logical. TRUE (default) will display, and FALSE will silence warnings and information messages helpful for troubleshooting. Global default can be set via options(mnirs.verbose = FALSE).

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.