resolve_interval: resolve start/end into time value vectors (no span applied)

View source: R/extract_interval_helpers.R

resolve_intervalR Documentation

resolve start/end into time value vectors (no span applied)

Description

resolve start/end into time value vectors (no span applied)

Usage

resolve_interval(
  start,
  end,
  t_vec,
  event_vec = NULL,
  env = rlang::caller_env()
)

Arguments

env

The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.