sigdrift_rate: Rate constant of a sigmoidal shape

View source: R/analyse_sigmoidal_drift.R

sigdrift_rateR Documentation

Rate constant of a sigmoidal shape

Description

The rate k such that the sigmoid of the given shape is a function of u = k * (t - xmid): 4 * slope / (B - A) for "symmetric", else slope * e / (B - A). Positive for a consistent fit, where slope and B - A share a sign.

Usage

sigdrift_rate(A, B, slope, shape)

Arguments

A

A numeric parameter for the starting asymptote of the response variable.

B

A numeric parameter for the ending asymptote of the response variable.

slope

A numeric parameter for the response rate dx/dt at the inflection xmid.

shape

Character; the 4-parameter sigmoidal shape. One of "symmetric" (default; logistic()), "gompertz" (gompertz()), or "gompertz_left" (gompertz_left()).

Value

A numeric rate in units of 1 / t.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.