warn_call: trim caller call to bare function name for warning headers...

View source: R/validate_mnirs.R

warn_callR Documentation

trim caller call to bare function name for warning headers env accepts an environment or a call, e.g. from sys.call(-1)

Description

trim caller call to bare function name for warning headers env accepts an environment or a call, e.g. from sys.call(-1)

Usage

warn_call(env = rlang::caller_env())

mnirs documentation built on Sept. 13, 2026, 1:06 a.m.