| artinis_intervals.xlsx | R Documentation |
Exported from Artinis Oxysoft, recorded on Oxymon MKIII at 50 Hz and exported at 10 Hz. Containing two 5-minute cycling work intervals and an ischaemic occlusion, placed on the vastus lateralis muscle site.
.xlsx file with header metadata and five columns and 20919 rows:
Sample index (divide by sample rate for seconds).
O2Hb: oxyhaemoglobin concentration change (\muM).
HHb: deoxyhaemoglobin concentration change (\muM).
Event marker (character).
Unmarked event label (character).
Channels are detected automatically from the file legend, or can be
specified explicitly for read_mnirs():
nirs_channels = c(O2Hb = 2, HHb = 3)
time_channel = c(sample = 1)
event_channel = c(event = 4)
interval_times = list( ## two intervals, post-exercise occlusion start = c(158, 999, 1750), end = c(493, 1333, 1961) )
Artinis Medical Systems. Oxymon MKIII, exported via Oxysoft desktop software (https://artinis.com/)
read_mnirs(), example_mnirs()
example_mnirs("artinis_intervals")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.