View source: R/extract_interval_helpers.R
| as_mnirs_interval | R Documentation |
coerce raw values to mnirs_interval objects
as_mnirs_interval(x, arg = "start", env = rlang::caller_env())
x |
A raw value or mnirs_interval object. |
arg |
Name of the argument for error messages. |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.