as_plot_data: Validate and bind a list of mnirs data frames for plotting

View source: R/plot.mnirs.R

as_plot_dataR Documentation

Validate and bind a list of mnirs data frames for plotting

Description

Validate and bind a list of mnirs data frames for plotting

Usage

as_plot_data(x)

mnirs documentation built on May 15, 2026, 9:07 a.m.