View source: R/aanalyse_kinetics_helpers.R
| build_fit_results | R Documentation |
Counterpart of build_na_results() for a successful fit: the
coefs/model/fitted_data/diag list expected by
analyse_kinetics_channels(), with fitted values and diagnostics
derived from model on the rows in keep.
build_fit_results(
coefs,
model,
x_fit,
t_fit,
valid,
keep = TRUE,
env = rlang::caller_env()
)
coefs |
A 1-row |
model |
A fitted model supporting |
x_fit, t_fit |
Numeric vectors of the channel fit window. |
valid |
The |
keep |
Logical row filter of the fit window used by |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
A named list with elements coefs, model, fitted_data,
and diag.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.