| create_mnirs_data | R Documentation |
Manually add class "mnirs" and metadata to an existing data frame.
create_mnirs_data(data, ...)
data |
A data frame with existing metadata (accessed with
|
... |
Additional arguments with metadata to add to the data frame. Can be either seperate named arguments or a list of named values.
|
Typically will only be called internally, but can be used to inject mnirs metadata into any data frame.
A tibble of class "mnirs". Metadata are stored
as attributes and can be accessed with attributes(data).
data <- data.frame(
A = 1:3,
B = seq(10, 30, 10),
C = seq(11, 33, 11)
)
attributes(data)
## inject metadata
nirs_data <- create_mnirs_data(
data,
nirs_channels = c("B", "C"),
time_channel = "A",
sample_rate = 1
)
attributes(nirs_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.