View source: R/read_mnirs_helpers.R
| detect_time_channel | R Documentation |
Detect time_channel from column names or time-formatted values
detect_time_channel(data, verbose = TRUE, env = rlang::caller_env())
data |
A data frame of class "mnirs" containing time series data and metadata. |
verbose |
Logical. |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.