device_patterns: Known channel names and detection patterns for supported...

device_patternsR Documentation

Known channel names and detection patterns for supported mNIRS devices

Description

Known channel names and detection patterns for supported mNIRS devices

Usage

device_patterns

Format

An object of class list of length 5.


mnirs documentation built on May 15, 2026, 9:07 a.m.