View source: R/analyse_exponential_drift.R
| expdrift_model | R Documentation |
Model function of SSexponential_drift(): exponential_drift() plus
the partial derivatives for the parameters written as bare symbols in
the call (see free_params()), so stats::nls() skips
stats::numericDeriv(). The hinge derivatives are one-sided at the
drift onset.
expdrift_model(t, A, B, tau, slope_B, drift_fraction, TD = NULL)
t |
A numeric vector of the predictor variable (time). |
A |
A numeric parameter for the starting baseline of the response variable. |
B |
A numeric parameter for the ending asymptote of the response variable. |
tau |
A numeric parameter for the time constant ( |
slope_B |
A numeric parameter for the linear drift rate |
drift_fraction |
A numeric fraction of the primary amplitude |
TD |
A numeric parameter for the time delay before the onset of the
exponential response, in units of the predictor variable |
A numeric vector of predicted values with a "gradient"
attribute when any parameter is free.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.