View source: R/analyse_exponential_drift.R
| expdrift_onset | R Documentation |
The time at which a monoexponential response reaches the drift_fraction
fraction of its amplitude, by the analytic inverse
TD - tau * log(1 - drift_fraction) (see exponential_drift()).
expdrift_onset(tau, drift_fraction, TD = NULL)
tau |
A numeric parameter for the time constant ( |
drift_fraction |
A numeric fraction of the primary amplitude |
TD |
A numeric parameter for the time delay before the onset of the
exponential response, in units of the predictor variable |
A numeric vector of onset times, TD = 0 when NULL.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.