View source: R/extract_intervals.R
| extract_intervals | R Documentation |
Extract intervals from "mnirs" time series data, specifying interval start and end boundaries by time value, event label, lap number, or sample index.
extract_intervals(
data,
nirs_channels = NULL,
time_channel = NULL,
event_channel = NULL,
sample_rate = NULL,
start = NULL,
end = NULL,
span = list(c(-60, 60)),
event_groups = c("distinct", "ensemble"),
zero_time = FALSE,
verbose = TRUE
)
data |
A data frame of class "mnirs" containing time series data and metadata. |
nirs_channels |
A character vector or a
|
time_channel |
A character string naming the time or sample column.
Must match a column name in
|
event_channel |
An optional character string giving the name of an event/lap column. The column may contain character event labels or integer lap numbers.
|
sample_rate |
An optional numeric sample rate (Hz) used to bin time
values for ensemble-averaging. If |
start |
Specifies where intervals begin. Either raw values – numeric
for time values, character for event labels, explicit integer (e.g. |
end |
Specifies where intervals end. Either raw values – numeric for
time values, character for event labels, explicit integer (e.g. |
span |
A one- or two-element numeric vector
|
event_groups |
Either a character string or a
|
zero_time |
Logical. Default is |
verbose |
Logical. Default is |
Interval start and end boundaries are specified using helper functions,
or by passing raw values directly:
by_time()Time values in units of time_channel.
by_label()Strings to match in event_channel.
All matching occurrences are returned.
by_lap()Lap numbers to match in event_channel. Resolves to the
first sample of each lap for start, and the last lap sample for end
by_sample()Integer sample indices (row numbers).
Raw values supplied to start/end are auto-coerced:
Numeric -> by_time()
Character -> by_label(),
Explicit integer (e.g. 2L) -> by_lap().
Use by_sample() explicitly for sample indices.
start and end can use different specification types (e.g., start by
label, end by time). When lengths differ, the shorter is recycled.
span additively expands the time span window around interval boundaries.
A two-value vector expands the start and end, respectively:
span = c(-60, 60) expands the start earlier by 60, and the end
later by 60. For example,
start = by_time(30), end = by_time(60), span = c(-5, 10) returns an
interval of [25, 70].
A single numeric value is recycled according to the sign: span = -60
becomes c(-60, 0) to expand the start earlier. span = 60 becomes
c(0, 60) to expand the end later.
If only start is specified alone, both span values expand the single
boundary window: start = by_time(30), span = c(-5, 60) returns
[25, 90].
When event_groups = "ensemble" or a list of numeric grouped intervals,
nirs_channels can be specified as a list of column names to override
ensemble-averaging across interval. For example, to exclude a channel
in one interval:
nirs_channels = list( c(A, B, C), c(A, C) ## channel "B" is excluded )
If all grouped intervals can include all nirs_channels, or if
event_groups = "distinct", a single nirs_channels character vector can
be supplied and recycled to all groups, or left as NULL for channels to
be taken from "mnirs" metadata.
event_groups controls whether extracted intervals are returned as distinct
data frames or ensemble-averaged.
"distinct"The default. Extract each interval and return a list of independent data frames.
"ensemble"Ensemble-average each specified nirs_channel across
all detected intervals and return a one-item list with a single data
frame.
list(c(1, 2), c(3, 4))Ensemble-average each specified
nirs_channel within each group and return a list with one data frame
for each group. Any intervals detected but not specified in
event_groups are returned as distinct.
event_groups lists can be named (e.g.
list(low = c(1, 2), high = c(3, 4))) and will pass those names to the
returned list of data frames.
When event_groups is a list of numeric interval numbers, list items in
nirs_channels and span are recycled to the number of groups. If lists
are only partially specified, the final item is recycled forward as needed.
Extra items are ignored.
A named list() of tibbles of class
"mnirs", each with metadata available via attributes().
## read example data
data <- read_mnirs(
example_mnirs("train.red"),
nirs_channels = c(
smo2_left = "SmO2 unfiltered",
smo2_right = "SmO2 unfiltered"
),
time_channel = c(time = "Timestamp (seconds passed)"),
zero_time = TRUE,
verbose = FALSE
) |>
## avoid issues ensemble-averaging irregular samples
resample_mnirs(method = "linear", verbose = FALSE)
## ensemble-average across multiple intervals
interval_list <- extract_intervals(
data, ## channels recycled to all intervals by default
nirs_channels = c(smo2_left, smo2_right),
start = by_time(368, 1084), ## manually identified interval start times
span = c(-20, 90), ## include the last 180-sec of each interval (recycled)
event_groups = "ensemble", ## ensemble-average across two intervals
zero_time = TRUE ## re-calculate common time to start from `0`
)
interval_list[[1L]]
if (requireNamespace("ggplot2", quietly = TRUE)) {
plot(interval_list[[1L]], time_labels = TRUE) +
ggplot2::geom_vline(xintercept = 0, linetype = "dotted")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.