View source: R/read_mnirs_helpers.R
| find_header_row | R Documentation |
nirs_channelsFind the header row containing all nirs_channels
find_header_row(raw, nirs_channels, start = 1L, env = rlang::caller_env())
raw |
A raw character data frame from |
nirs_channels |
Character vector of original column names. |
start |
Integer row index to try first, from |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.