View source: R/aanalyse_kinetics_helpers.R
| free_params | R Documentation |
A parameter written as a bare symbol in the model call is free (fitted
by stats::nls()); one written as a constant or expression is fixed.
Used by the model functions to return gradient columns for the free
parameters only, in call order, as stats::nls() indexes the
"gradient" attribute by position.
free_params(mCall, params)
mCall |
A matched call to the model function. |
params |
Character vector of the model parameter names. |
A character vector; the subset of params that are free.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.