View source: R/aanalyse_kinetics_helpers.R
| full_coefs | R Documentation |
Combine fitted and fixed coefficients into the full parameter vector
full_coefs(model, params, fix = list())
model |
An nls model of the free parameters. |
params |
Character vector of parameter names in model order. |
fix |
Named list of fixed parameter values. Non-numeric elements
(e.g. a model |
A named numeric vector ordered by params containing the
fitted coefficients with fixed values merged in.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.