Skip to contents

Custom mnirs colour palette

Usage

palette_mnirs(...)

Arguments

...

Either a single numeric specifying the number of colours to return, or character strings specifying colour names. If empty, all colours are returned.

Value

Named (when selecting by name) or unnamed character vector of hex colours.

Examples

scales::show_col(palette_mnirs())

scales::show_col(palette_mnirs(2))

scales::show_col(palette_mnirs("red", "orange"))