| palette_mnirs | R Documentation |
Custom mnirs colour palette
palette_mnirs(...)
... |
Either a single numeric specifying the number of colours to return, or character strings specifying colour names. If empty, all colours are returned. |
Named (when selecting by name) or unnamed character vector of hex colours.
theme_mnirs(), scale_colour_mnirs()
scales::show_col(palette_mnirs())
scales::show_col(palette_mnirs(2))
scales::show_col(palette_mnirs("red", "orange"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.