| pionirs_occlusion.ftn | R Documentation |
Exported from PIONIRS software at 1 Hz, one channel. Containing baseline, arterial occlusion, and recovery phases marked by event tags, from the thenar eminence (CH1).
tab-separated .ftn file with 15 columns and 700 rows:
Sample index.
Elapsed time (seconds).
Absorption coefficient at wavelengths 1 (685 nm) and 2 (830 nm; cm^-1).
Reduced scattering coefficient at wavelengths 1 and 2 (cm^-1).
Differential pathlength factor at wavelengths 1
and 2 (\muM).
Oxyhaemoglobin concentration (\muM).
Deoxyhaemoglobin concentration (\muM).
Total haemoglobin concentration (\muM).
Tissue oxygen saturation (%).
Data quality index (0-1).
Event marker (integer). 0 - no tag; 1 - manual tag;
2 - automatic tag from external trigger; 3 - automatic protocol-
specific tag from the measurement software
Event label text.
Channels are detected automatically, or can be specified explicitly for
read_mnirs():
nirs_channels = c("StO2", "O2Hb", "HHb", "THb")
time_channel = c("Time")
event_channel = c("TagLabel")
interval_times = list(start = 91, end = 391)
PIONIRS S.r.l. (https://www.pionirs.com/)
read_mnirs(), example_mnirs()
example_mnirs("pionirs")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.