portamon_oxcap.xlsx: 10 Hz Artinis Oxysoft export recorded with Portamon

portamon_oxcap.xlsxR Documentation

10 Hz Artinis Oxysoft export recorded with Portamon

Description

Exported from Artinis Oxysoft, recorded on Portamon at 10 Hz on the vastus lateralis muscle. Containing two trials of repeated occlusion oxidative capacity testing, each with 17 occlusions.

Format

.xlsx file with header metadata and six columns and 7943 rows:

Column 1

Sample index (divide by sample rate for seconds).

Column 2

tHb: total haemoglobin concentration change (\muM).

Column 3

HHb: deoxyhaemoglobin concentration change (\muM).

Column 4

O2Hb: oxyhaemoglobin concentration change (\muM).

Column 5

Event marker (character).

Column 6

Unmarked event label (character).

Channels are detected automatically from the file legend (the unmarked label column is named "labels"), or can be specified explicitly for read_mnirs():

  • nirs_channels = c(THb = 2, HHb = 3, O2Hb = 4)

  • time_channel = c(sample = 1)

  • event_channel = c(event = 5, label = "labels")

Artinis Medical Systems. Portamon, exported via Oxysoft desktop software (https://artinis.com/)

See Also

read_mnirs(), example_mnirs()

Examples

example_mnirs("portamon")


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.