recycle_param: Recycle parameter to match number of events

View source: R/extract_interval_helpers.R

recycle_paramR Documentation

Recycle parameter to match number of events

Description

Recycle an argument vector to a list or repeat the last list item to match the number of events.

Usage

recycle_param(param, n_events, event_groups, verbose = TRUE)

mnirs documentation built on May 15, 2026, 9:07 a.m.