View source: R/read_mnirs_helpers.R
| select_channels | R Documentation |
Original names are made unique to match rename_duplicates(names(data));
duplicated new names are made unique with a warning. Channel names take
priority over clashing names of other data columns. Columns are ordered
by role, followed by all remaining columns when keep_all = TRUE.
select_channels(
data,
channels,
keep_all = FALSE,
verbose = TRUE,
env = rlang::caller_env()
)
data |
The named character data table. |
channels |
A list of named |
verbose |
Logical. |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
A list of the selected data and channels as new names by
role.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.