View source: R/signif_trailing.R
| seq_range | R Documentation |
Creates a numeric sequence spanning the range of input vector with either a specified step size or a desired output length.
seq_range(
x,
by = 1,
length.out = NULL,
direction = c("up", "down"),
env = rlang::caller_env()
)
x |
A numeric vector. |
by |
A numeric step size for the output sequence. Default is |
length.out |
A positive integer giving the desired length of the
sequence. Default is |
direction |
Order of returned vector. Either |
env |
The calling environment or a defused call, used to report errors and warnings as coming from the user-facing function rather than the validator. |
The output vector will likely be a different length than the input x.
A numeric vector spanning the range of the input x.
seq(), range()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.