sigdrift_onset: Drift onset time of the sigmoidal-drift model

View source: R/analyse_sigmoidal_drift.R

sigdrift_onsetR Documentation

Drift onset time of the sigmoidal-drift model

Description

The time at which a sigmoid of the given shape reaches the drift_fraction fraction of its amplitude, by the analytic inverse of each shape (see sigmoidal_drift()). Vectorised over the numeric parameters; shape is a single string.

Usage

sigdrift_onset(A, B, xmid, slope, drift_fraction, shape)

Arguments

A

A numeric parameter for the starting asymptote of the response variable.

B

A numeric parameter for the ending asymptote of the response variable.

xmid

A numeric parameter for the time at the inflection point (the steepest point) of the curve, in units of the predictor variable t.

slope

A numeric parameter for the response rate dx/dt at the inflection xmid.

drift_fraction

A numeric fraction of the primary amplitude B - A in ⁠(0.5, 1)⁠ at which the linear drift begins, where the sigmoid reaches A + drift_fraction * (B - A).

shape

Character; the 4-parameter sigmoidal shape. One of "symmetric" (default; logistic()), "gompertz" (gompertz()), or "gompertz_left" (gompertz_left()).

Value

A numeric vector of onset times.


mnirs documentation built on Sept. 13, 2026, 1:06 a.m.