View source: R/analyse_sigmoidal_drift.R
| sigdrift_onset | R Documentation |
The time at which a sigmoid of the given shape reaches the
drift_fraction fraction of its amplitude, by the analytic inverse of
each shape (see sigmoidal_drift()). Vectorised over the numeric
parameters; shape is a single string.
sigdrift_onset(A, B, xmid, slope, drift_fraction, shape)
A |
A numeric parameter for the starting asymptote of the response variable. |
B |
A numeric parameter for the ending asymptote of the response variable. |
xmid |
A numeric parameter for the time at the inflection point (the
steepest point) of the curve, in units of the predictor variable |
slope |
A numeric parameter for the response rate |
drift_fraction |
A numeric fraction of the primary amplitude |
shape |
Character; the 4-parameter sigmoidal shape. One of
|
A numeric vector of onset times.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.