View source: R/analyse_sigmoidal_drift.R
| sigdrift_rate | R Documentation |
The rate k such that the sigmoid of the given shape is a function of
u = k * (t - xmid): 4 * slope / (B - A) for "symmetric", else
slope * e / (B - A). Positive for a consistent fit, where slope and
B - A share a sign.
sigdrift_rate(A, B, slope, shape)
A |
A numeric parameter for the starting asymptote of the response variable. |
B |
A numeric parameter for the ending asymptote of the response variable. |
slope |
A numeric parameter for the response rate |
shape |
Character; the 4-parameter sigmoidal shape. One of
|
A numeric rate in units of 1 / t.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.