View source: R/signif_trailing.R
| wrap | R Documentation |
Rotates vector elements by moving the first n elements to the end.
wrap(x, n = 0L)
x |
A vector. |
n |
An integer specifying number of elements to move from start to end.
Default is |
The function:
Returns x unchanged if n = 0.
Moves first n elements to the end of the vector.
For negative n, effectively moves elements from end to start.
If n is larger than length(x), positions wrap around.
A vector with all the same elements as x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.